@@ -31,6 +31,11 @@ def make_date_filter_template(path, file, name, in_format = None):
         else:
             temp_out.write('{{ model["'+name+'"]|date_fmt("%d %b %y","'+ in_format +'")}}')
 
+def make_markdown_filter_template(path, file, name):
+    with open(os.path.join(path,file),'w') as temp_out:
+            temp_out.write("{{ model['"+name+"']|markdown_fmt }}")
+
+
 @pytest.fixture()
 def get_test_template_engine():
     path = os.path.join(os.getcwd(),'test_templates')
@@ -46,6 +51,7 @@ def get_test_template_engine():
     make_dict_template(path, "target.html", "target")
     make_date_filter_template(path, "filter.html", "test_date")
     make_date_filter_template(path, "filter_cust.html", "test_date","%d-%m-%Y")
+    make_markdown_filter_template(path, "filter_markdown.html","test_markdown")
 
     yield TemplateEngine(path)
     shutil.rmtree(path)
@@ -204,3 +210,21 @@ def test_date_filter_in_template_with_custom_input_format(get_test_template_engi
         page_link = "filter_cust.html"
         )
     assert result == "04 Apr 21"
+
+def test_markdown_filter_directly(get_test_template_engine):
+    markdown = "# Header"
+    html     = "<h1>Header</h1>"
+    test_md = get_test_template_engine._markdown_to_html5_filter(markdown)
+    assert test_md == html
+
+def test_markdown_filter_in_teamplate(get_test_template_engine):
+    markdown = "## Header"
+    html     = "<h2>Header</h2>"
+    get_test_template_engine.model = {"test_markdown":markdown}
+    get_test_template_engine.links = []
+    result = get_test_template_engine.generate_page(
+    template="filter_markdown.html",
+    save_path = None,
+    page_link = "filter_markdown.html"
+    )
+    assert result == html
