@@ -72,7 +72,7 @@ def get_valid_pages_with_lists():
 def get_basic_website(pages):
     return {
         'name':'test',
-        'template':'tests/templates',
+        'template':'templates',
         'pages':pages
     }
 
