@@ -4,9 +4,12 @@ Responsible for managing the templating system and generating pages
 
 import datetime
 
+import markdown
 from jinja2 import FileSystemLoader
 from jinja2 import Environment
 from jinja2.exceptions import TemplateNotFound
+from jinja2.filters import do_mark_safe
+
 
 class TemplateEngine():
     """Provides a wrapper for the templating engine"""
@@ -16,6 +19,7 @@ class TemplateEngine():
             autoescape = True
         )
         self.env.filters["date_fmt"] = TemplateEngine._date_filter
+        self.env.filters["markdown_fmt"] = TemplateEngine._markdown_to_html5_filter
 
         self._template_path = template_path
         self._model = {}
@@ -32,6 +36,12 @@ class TemplateEngine():
 
         return date_in.strftime(date_format)
 
+    @staticmethod
+    def _markdown_to_html5_filter(md_text):
+        """ converts markdown strings to html5"""
+        return do_mark_safe(
+            markdown.markdown(md_text, output_format="html5")
+            )
 
     @property
     def template_path(self):
@@ -70,7 +80,7 @@ class TemplateEngine():
         )
 
         if save_path is not None:
-            with open(save_path,'w') as page_out:
+            with open(save_path,'w', encoding="utf-8") as page_out:
                 page_out.write(page)
             return page
 
